#' causal.decomp: Causal Decomposition Analysis.
#'
#' The causal.decomp package provides six important functions:
#' mmi, smi, pocr, sensitivity, ind.decomp, and ind.sens.
#'
"_PACKAGE"
#'
#' @importFrom MASS gamma.shape polr
#' @importFrom nnet multinom
#' @importFrom PSweight SumStat
#' @importFrom parallel detectCores mclapply
#' @importFrom stats Gamma as.formula binomial coef
#'   formula gaussian glm inverse.gaussian lm
#'   model.frame pcauchy plogis pnorm poisson
#'   predict quantile rbinom rgamma rmultinom
#'   rnorm rpois terms update
#' @importFrom utils packageDescription
#' @importFrom rlang exprs
#' @importFrom modelObj buildModelObj
#' @importFrom DynTxRegime optimalClass optTx
#' @importFrom rpart rpart rpart.control
#' @importFrom magrittr %>%
#' @importFrom dplyr mutate
#' @importFrom parallel mclapply
#' @importFrom distr AbscontDistribution r
#' @importFrom knitr kable
NULL
#> NULL
